import { ActivityType } from '../enums';
import { ActivityZone, Comment, DetailedActivity, Lap, SummaryActivity, SummaryAthlete } from '../models';
import { Request } from '../request';
declare type CreateActivityRequest = {
    name: string;
    type: ActivityType;
    start_date_local: string;
    elapsed_time: number;
    description?: string;
    distance?: number;
    trainer?: number;
    commute?: number;
};
declare type GetActivityByIdRequest = {
    id: number;
    include_all_efforts?: boolean;
};
declare type GetCommentsByActivityIdRequest = {
    id: number;
    page?: number;
    per_page?: number;
};
declare type GetKudoersByActivityIdRequest = {
    id: number;
    page?: number;
    per_page?: number;
};
declare type GetLapsByActivityIdRequest = {
    id: number;
};
declare type GetPhotosByActivityIdRequest = {
    id: number;
    photo_sources?: boolean;
    size?: number;
};
declare type GetZonesByActivityIdRequest = {
    id: number;
};
declare type GetLoggedInAthleteActivitiesRequest = {
    before?: number;
    after?: number;
    page?: number;
    per_page?: number;
};
declare type UpdateActivityByIdRequest = {
    id: number;
    name?: string;
    type?: ActivityType;
    start_date_local?: string;
    elapsed_time?: number;
    description?: string;
    distance?: number;
    trainer?: number;
    commute?: number;
};
export declare class Activities {
    private readonly request;
    constructor(request: Request);
    createActivity(params: CreateActivityRequest): Promise<DetailedActivity>;
    getActivityById(params: GetActivityByIdRequest): Promise<DetailedActivity>;
    getCommentsByActivityId(params: GetCommentsByActivityIdRequest): Promise<Comment[]>;
    getKudoersByActivityId(params: GetKudoersByActivityIdRequest): Promise<SummaryAthlete[]>;
    getLapsByActivityId(params: GetLapsByActivityIdRequest): Promise<Lap[]>;
    getPhotosByActivityId(params: GetPhotosByActivityIdRequest): Promise<Lap[]>;
    getLoggedInAthleteActivities(params?: GetLoggedInAthleteActivitiesRequest): Promise<SummaryActivity[]>;
    getZonesByActivityId(params: GetZonesByActivityIdRequest): Promise<ActivityZone[]>;
    updateActivityById(params: UpdateActivityByIdRequest): Promise<DetailedActivity>;
}
export {};
